import { App } from 'vue';
import { InjectionKey } from 'vue';

declare enum ConfirmTypeEnum {
    basic = "basic",
    soft = "soft",
    hard = "hard"
}

declare interface DialogOptions {
    message: MessageWithTitle;
    html: boolean;
    loader: boolean;
    reverse: boolean;
    backdropClose: boolean;
    okText: string;
    cancelText: string;
    type: ConfirmTypeEnum;
    clicksCount: number;
    animation: 'zoom' | 'bounce' | 'fade';
    customClass: {
        [k: string]: string;
    };
    verification: string;
    verificationHelp: string;
    promptHelp: string;
}

declare interface DialogPluginOptions extends Omit<DialogWindowOptions, 'id'> {
}

declare type DialogResolverPayload = {
    data: string;
    close?: () => void;
    node?: HTMLElement;
} | {
    canceled: boolean;
};

declare enum DialogTypeEnum {
    alert = "alert",
    confirm = "confirm",
    prompt = "prompt"
}

declare interface DialogWindowOptions extends DialogOptions {
    message: MessageWithTitle;
    window: DialogTypeEnum;
    promiseResolver: (payload?: DialogResolverPayload) => void;
}

export declare const injectionKey: InjectionKey<PromiseDialog>;

declare type Message = MessageWithTitle | String;

declare type MessageWithTitle = {
    title: string;
    body: string;
};

export declare class PromiseDialog {
    private readonly contextApp?;
    private readonly globalOptions?;
    private dgApp;
    private dgAppComponentInstance;
    /* Excluded from this release type: mounted */
    constructor(contextApp?: App, globalOptions?: Partial<DialogPluginOptions>);
    private open;
    alert(message?: Message, options?: Partial<DialogWindowOptions>): Promise<DialogResolverPayload>;
    confirm(message?: Message, options?: Partial<DialogWindowOptions>): Promise<DialogResolverPayload>;
    prompt(message?: Message, options?: Partial<DialogWindowOptions>): Promise<DialogResolverPayload>;
    /* Excluded from this release type: mountIfNotMounted */
    private destroy;
    /* Excluded from this release type: dialogInstance */
    static install(app: App<Element>, options?: DialogPluginOptions): void;
    static getInstance(): PromiseDialog;
    static installStandalone(options?: DialogPluginOptions): PromiseDialog;
}

export declare const propertyKey = "$dialog";

export { }
declare module 'vue' {
    export interface ComponentCustomProperties {
        $dialog: typeof PromiseDialog;
    }
}
